@@ -14,19 +14,28 @@ from streamlink.plugin.api import validate
 from streamlink.stream.hls import HLSStream
 from streamlink.utils.url import update_qsd
 
+
 log = logging.getLogger(__name__)
 
 
-@pluginmatcher(re.compile(r"""https?://(?:www\.)?(?:
-    chetv
-    |
-    ctc(?:love)?
-    |
-    domashniy
-)\.ru/(?:live|online)""", re.VERBOSE))
-@pluginmatcher(re.compile(r"https?://player\.mediavitrina\.ru/.+/player\.html"))
+@pluginmatcher(
+    name="chetv",
+    pattern=re.compile(r"https?://(?:www\.)?chetv\.ru/(?:live|online)"),
+)
+@pluginmatcher(
+    name="ctc",
+    pattern=re.compile(r"https?://(?:www\.)?ctc(?:love)?\.ru/(?:live|online)"),
+)
+@pluginmatcher(
+    name="domashniy",
+    pattern=re.compile(r"https?://(?:www\.)?domashniy\.ru/(?:live|online)"),
+)
+@pluginmatcher(
+    name="mediavitrina",
+    pattern=re.compile(r"https?://player\.mediavitrina\.ru/.+/player\.html"),
+)
 class MediaVitrina(Plugin):
-    _re_url_json = re.compile(r"https://media\.mediavitrina\.ru/(?:proxy)?api/v3/\w+/playlist/[\w-]+_as_array\.json[^\"']+")
+    _re_url_json = re.compile(r"https://media\.mediavitrina\.ru/(?:proxy)?api/v3/[\w-]+/playlist/[\w-]+_as_array\.json[^\"']+")
 
     def _get_streams(self):
         self.session.http.headers.update({"Referer": self.url})
@@ -41,32 +50,41 @@ class MediaVitrina(Plugin):
                 "https://ctc.ru/api/page/v1/online/",
                 schema=validate.Schema(
                     validate.parse_json(),
-                    {"content": validate.all(
-                        [dict],
-                        validate.filter(lambda n: n.get("type") == "on-air"),
-                        [{"onAirLink": validate.url(netloc="player.mediavitrina.ru")}],
-                        validate.get((0, "onAirLink"))
-                    )},
-                    validate.get("content")
-                )
+                    {
+                        "content": validate.all(
+                            [dict],
+                            validate.filter(lambda n: n.get("type") == "on-air"),
+                            [{"onAirLink": validate.url(netloc="player.mediavitrina.ru")}],
+                            validate.get((0, "onAirLink")),
+                        ),
+                    },
+                    validate.get("content"),
+                ),
             )
         else:
             # https://chetv.ru/online/
             # https://ctclove.ru/online/
             # https://domashniy.ru/online/
-            url_player = self.session.http.get(self.url, schema=validate.Schema(
-                validate.parse_html(),
-                validate.xml_xpath_string(".//iframe[starts-with(@src,'https://player.mediavitrina.ru/')]/@src"),
-            ), acceptable_status=(200, 403, 404))
+            url_player = self.session.http.get(
+                self.url,
+                schema=validate.Schema(
+                    validate.parse_html(),
+                    validate.xml_xpath_string(".//iframe[starts-with(@src,'https://player.mediavitrina.ru/')]/@src"),
+                ),
+                acceptable_status=(200, 403, 404),
+            )
 
         if not url_player:
             return
 
         log.debug(f"url_player={url_player}")
-        script_data = self.session.http.get(url_player, schema=validate.Schema(
-            validate.parse_html(),
-            validate.xml_xpath_string(".//script[contains(text(),'media.mediavitrina.ru/')]/text()"),
-        ))
+        script_data = self.session.http.get(
+            url_player,
+            schema=validate.Schema(
+                validate.parse_html(),
+                validate.xml_xpath_string(".//script[contains(text(),'media.mediavitrina.ru/')]/text()"),
+            ),
+        )
         if not script_data:
             log.debug("invalid script_data")
             return
@@ -87,14 +105,16 @@ class MediaVitrina(Plugin):
                 validate.parse_json(),
                 {"result": {"token": str}},
                 validate.get("result"),
-            ))
+            ),
+        )
         url = self.session.http.get(
             update_qsd(url_json, qsd=res_token),
             schema=validate.Schema(
                 validate.parse_json(),
                 {"hls": [validate.url()]},
                 validate.get(("hls", 0)),
-            ))
+            ),
+        )
 
         if not url:
             return
