@@ -3,22 +3,19 @@ from __future__ import annotations
 import logging
 import re
 import struct
-from collections.abc import Mapping
-from concurrent.futures import Future
-from datetime import datetime, timedelta
-from typing import TYPE_CHECKING, Any, ClassVar, TypeVar
+import warnings
+from datetime import timedelta
+from typing import TYPE_CHECKING, Any, ClassVar, Literal, TypeVar
 from urllib.parse import urlparse
 
 from requests import Response
 from requests.exceptions import ChunkedEncodingError, ConnectionError, ContentDecodingError, InvalidSchema  # noqa: A004
 
-from streamlink.buffers import RingBuffer
-from streamlink.exceptions import StreamError
-from streamlink.session import Streamlink
+from streamlink.exceptions import StreamError, StreamlinkDeprecationWarning
 from streamlink.stream.ffmpegmux import FFMPEGMuxer, MuxedStream
 from streamlink.stream.filtered import FilteredStream
-from streamlink.stream.hls.m3u8 import M3U8, M3U8Parser, parse_m3u8
-from streamlink.stream.hls.segment import ByteRange, HLSPlaylist, HLSSegment, Key, Map, Media
+from streamlink.stream.hls.m3u8 import M3U8Parser, parse_m3u8
+from streamlink.stream.hls.segment import HLSSegment
 from streamlink.stream.http import HTTPStream
 from streamlink.stream.segmented import SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter
 from streamlink.utils.cache import LRUCache
@@ -29,6 +26,15 @@ from streamlink.utils.times import now
 
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+    from concurrent.futures import Future
+    from datetime import datetime
+
+    from streamlink.buffers import RingBuffer
+    from streamlink.session import Streamlink
+    from streamlink.stream.hls.m3u8 import M3U8
+    from streamlink.stream.hls.segment import ByteRange, HLSPlaylist, Key, Map, Media
+
     try:
         from typing import Self  # type: ignore[attr-defined]
     except ImportError:
@@ -302,45 +308,66 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
 
     SEGMENT_QUEUE_TIMING_THRESHOLD_MIN = 5.0
 
+    reload_attempts: int
+    reload_time: float | Literal["segment", "live-edge"]
+
+    _RELOAD_TIME_MIN = 2.0
+    _RELOAD_TIME_DEFAULT = 6.0
+
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
         self.playlist_changed = False
         self.playlist_end: int | None = None
         self.playlist_targetduration: float = 0
-        self.playlist_sequence: int = -1
         self.playlist_sequence_last: datetime = now()
         self.playlist_segments: list[HLSSegment] = []
 
-        self.playlist_reload_last: datetime = now()
-        self.playlist_reload_time: float = 6
-        self.playlist_reload_time_override = self.session.options.get("hls-playlist-reload-time")
-        self.playlist_reload_retries = self.session.options.get("hls-playlist-reload-attempts")
         self.segment_queue_timing_threshold_factor = self.session.options.get("hls-segment-queue-threshold")
         self.live_edge = self.session.options.get("hls-live-edge")
         self.duration_offset_start = int(self.stream.start_offset + (self.session.options.get("hls-start-offset") or 0))
-        self.duration_limit = self.stream.duration or (
-            int(self.session.options.get("hls-duration")) if self.session.options.get("hls-duration") else None
-        )
         self.hls_live_restart = self.stream.force_restart or self.session.options.get("hls-live-restart")
 
-        if str(self.playlist_reload_time_override).isnumeric() and float(self.playlist_reload_time_override) >= 2:
-            self.playlist_reload_time_override = float(self.playlist_reload_time_override)
-        elif self.playlist_reload_time_override not in ["segment", "live-edge"]:
-            self.playlist_reload_time_override = 0
+        self.duration_limit = self.stream.duration or self.duration_limit
+
+        self.reload_attempts = self.session.options.get("hls-playlist-reload-attempts")
+        self.reload_time = self.session.options.get("hls-playlist-reload-time")
+        if str(self.reload_time).isnumeric() and float(self.reload_time) >= self._RELOAD_TIME_MIN:
+            self.reload_time = float(self.reload_time)
+        elif self.reload_time not in ("segment", "live-edge"):
+            self.reload_time = 0.0
+        self._reload_time: float = self._RELOAD_TIME_DEFAULT
+        self._reload_last: datetime = now()
+
+    def _warn_playlist_sequence(self):
+        warnings.warn(
+            f"{self.__class__.__name__}.playlist_sequence has been moved to SegmentedStreamWorker.sequence",
+            StreamlinkDeprecationWarning,
+            stacklevel=3,
+        )
+
+    @property
+    def playlist_sequence(self):
+        self._warn_playlist_sequence()
+        return self.sequence
+
+    @playlist_sequence.setter
+    def playlist_sequence(self, value):
+        self._warn_playlist_sequence()
+        self.sequence = value
 
     def _fetch_playlist(self) -> Response:
         res = self.session.http.get(
             self.stream.url,
             exception=StreamError,
-            retries=self.playlist_reload_retries,
+            retries=self.reload_attempts,
             **self.reader.request_params,
         )
         res.encoding = "utf-8"
 
         return res
 
-    def reload_playlist(self):
+    def reload(self):
         if self.closed:  # pragma: no cover
             return
 
@@ -361,24 +388,24 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
             raise StreamError("Streams containing I-frames only are not playable")
 
         self.playlist_targetduration = playlist.targetduration or 0
-        self.playlist_reload_time = self._playlist_reload_time(playlist)
+        self._reload_time = self._get_reload_time(playlist)
 
         if playlist.segments:
             self.process_segments(playlist)
 
-    def _playlist_reload_time(self, playlist: M3U8[HLSSegment, HLSPlaylist]) -> float:
-        if self.playlist_reload_time_override == "segment" and playlist.segments:
+    def _get_reload_time(self, playlist: M3U8[HLSSegment, HLSPlaylist]) -> float:
+        if self.reload_time == "segment" and playlist.segments:
             return playlist.segments[-1].duration
-        if self.playlist_reload_time_override == "live-edge" and playlist.segments:
+        if self.reload_time == "live-edge" and playlist.segments:
             return sum(s.duration for s in playlist.segments[-max(1, self.live_edge - 1) :])
-        if type(self.playlist_reload_time_override) is float and self.playlist_reload_time_override > 0:
-            return self.playlist_reload_time_override
+        if isinstance(self.reload_time, float) and self.reload_time > 0:
+            return self.reload_time
         if playlist.targetduration:
             return playlist.targetduration
         if playlist.segments:
             return sum(s.duration for s in playlist.segments[-max(1, self.live_edge - 1) :])
 
-        return self.playlist_reload_time
+        return self._reload_time
 
     def process_segments(self, playlist: M3U8[HLSSegment, HLSPlaylist]) -> None:
         segments = playlist.segments
@@ -391,21 +418,21 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
         self.playlist_segments = segments
 
         if not self.playlist_changed:
-            self.playlist_reload_time = max(self.playlist_reload_time / 2, 1)
+            self._reload_time = max(self._reload_time / 2, 1)
 
         if playlist.is_endlist:
             self.playlist_end = last_segment.num
 
-        if self.playlist_sequence < 0:
+        if self.sequence < 0:
             if self.playlist_end is None and not self.hls_live_restart:
                 edge_index = -(min(len(segments), max(int(self.live_edge), 1)))
                 edge_segment = segments[edge_index]
-                self.playlist_sequence = edge_segment.num
+                self.sequence = edge_segment.num
             else:
-                self.playlist_sequence = first_segment.num
+                self.sequence = first_segment.num
 
     def valid_segment(self, segment: HLSSegment) -> bool:
-        return segment.num >= self.playlist_sequence
+        return segment.num >= self.sequence
 
     def _segment_queue_timing_threshold_reached(self) -> bool:
         if self.segment_queue_timing_threshold_factor <= 0:
@@ -438,12 +465,12 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
         return default
 
     def iter_segments(self):
-        self.playlist_reload_last \
+        self._reload_last \
             = self.playlist_sequence_last \
             = now()  # fmt: skip
 
         try:
-            self.reload_playlist()
+            self.reload()
         except StreamError as err:
             log.error(f"{err}")
             self.reader.close()
@@ -456,7 +483,7 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
             self.duration_offset_start = -self.duration_offset_start
 
         if self.duration_offset_start != 0:
-            self.playlist_sequence = self.duration_to_sequence(self.duration_offset_start, self.playlist_segments)
+            self.sequence = self.duration_to_sequence(self.duration_offset_start, self.playlist_segments)
 
         if self.playlist_segments:
             log.debug(
@@ -469,12 +496,11 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
                 "; ".join([
                     f"Start offset: {self.duration_offset_start}",
                     f"Duration: {self.duration_limit}",
-                    f"Start Sequence: {self.playlist_sequence}",
+                    f"Start Sequence: {self.sequence}",
                     f"End Sequence: {self.playlist_end}",
                 ]),
             )
 
-        total_duration = 0
         while not self.closed:
             queued = False
             for segment in self.playlist_segments:
@@ -482,32 +508,15 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
                     continue
 
                 log.debug(f"Adding segment {segment.num} to queue")
-                offset = segment.num - self.playlist_sequence
-                if offset > 0:
-                    log.warning(
-                        (
-                            f"Skipped segments {self.playlist_sequence}-{segment.num - 1} after playlist reload. "
-                            if offset > 1
-                            else f"Skipped segment {self.playlist_sequence} after playlist reload. "
-                        )
-                        + "This is unsupported and will result in incoherent output data.",
-                    )
 
                 yield segment
                 queued = True
 
-                total_duration += segment.duration
-                if self.duration_limit and total_duration >= self.duration_limit:
-                    log.info(f"Stopping stream early after {self.duration_limit}")
-                    return
-
                 if self.closed:  # pragma: no cover
                     return
 
-                self.playlist_sequence = segment.num + 1
-
             # End of stream
-            if self.closed or self.playlist_end is not None and (not queued or self.playlist_sequence > self.playlist_end):
+            if self.closed or self.playlist_end is not None and (not queued or self.sequence > self.playlist_end):
                 return
 
             if queued:
@@ -518,19 +527,19 @@ class HLSStreamWorker(SegmentedStreamWorker[HLSSegment, Response]):
             # Exclude playlist fetch+processing time from the overall playlist reload time
             # and reload playlist in a strict time interval
             time_completed = now()
-            time_elapsed = max(0.0, (time_completed - self.playlist_reload_last).total_seconds())
-            time_wait = max(0.0, self.playlist_reload_time - time_elapsed)
+            time_elapsed = max(0.0, (time_completed - self._reload_last).total_seconds())
+            time_wait = max(0.0, self._reload_time - time_elapsed)
             if self.wait(time_wait):
                 if time_wait > 0:
                     # If we had to wait, then don't call now() twice and instead reference the timestamp from before
                     # the wait() call, to prevent a shifting time offset due to the execution time.
-                    self.playlist_reload_last = time_completed + timedelta(seconds=time_wait)
+                    self._reload_last = time_completed + timedelta(seconds=time_wait)
                 else:
                     # Otherwise, get the current time, as the reload interval already has shifted.
-                    self.playlist_reload_last = now()
+                    self._reload_last = now()
 
                 try:
-                    self.reload_playlist()
+                    self.reload()
                 except StreamError as err:
                     log.warning(f"Failed to reload playlist: {err}")
 
@@ -571,7 +580,6 @@ class MuxedHLSStream(MuxedStream[TMuxedHLSStream_co]):
         video: str,
         audio: str | list[str],
         hlsstream: type[TMuxedHLSStream_co] | None = None,
-        url_master: str | None = None,
         multivariant: M3U8 | None = None,
         force_restart: bool = False,
         ffmpeg_options: Mapping[str, Any] | None = None,
@@ -582,7 +590,6 @@ class MuxedHLSStream(MuxedStream[TMuxedHLSStream_co]):
         :param video: Video stream URL
         :param audio: Audio stream URL or list of URLs
         :param hlsstream: The :class:`HLSStream` class of each sub-stream
-        :param url_master: The URL of the HLS playlist's multivariant playlist (deprecated)
         :param multivariant: The parsed multivariant playlist
         :param force_restart: Start from the beginning after reaching the playlist's end
         :param ffmpeg_options: Additional keyword arguments passed to :class:`ffmpegmux.FFMPEGMuxer`
@@ -601,22 +608,23 @@ class MuxedHLSStream(MuxedStream[TMuxedHLSStream_co]):
         # https://github.com/python/mypy/issues/18017
         TStream: type[TMuxedHLSStream_co] = hlsstream if hlsstream is not None else HLSStream  # type: ignore[assignment]
         substreams = [
-            TStream(session, url, force_restart=force_restart, name=None if idx == 0 else "audio", **kwargs)
+            TStream(
+                session,
+                url,
+                multivariant=multivariant,
+                force_restart=force_restart,
+                name=None if idx == 0 else "audio",
+                **kwargs,
+            )
             for idx, url in enumerate(tracks)
         ]
         ffmpeg_options = ffmpeg_options or {}
 
         super().__init__(session, *substreams, format="mpegts", maps=maps, **ffmpeg_options)
-        self._url_master = url_master
         self.multivariant = multivariant if multivariant and multivariant.is_master else None
 
-    @property
-    def url_master(self):
-        """Deprecated"""
-        return self.multivariant.uri if self.multivariant and self.multivariant.uri else self._url_master
-
     def to_manifest_url(self):
-        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else self.url_master
+        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else None
 
         if url is None:
             return super().to_manifest_url()
@@ -637,7 +645,6 @@ class HLSStream(HTTPStream):
         self,
         session: Streamlink,
         url: str,
-        url_master: str | None = None,
         multivariant: M3U8 | None = None,
         name: str | None = None,
         force_restart: bool = False,
@@ -648,7 +655,6 @@ class HLSStream(HTTPStream):
         """
         :param session: Streamlink session instance
         :param url: The URL of the HLS playlist
-        :param url_master: The URL of the HLS playlist's multivariant playlist (deprecated)
         :param multivariant: The parsed multivariant playlist
         :param name: Optional name suffix for the stream's worker and writer threads
         :param force_restart: Start from the beginning after reaching the playlist's end
@@ -658,7 +664,6 @@ class HLSStream(HTTPStream):
         """
 
         super().__init__(session, url, **kwargs)
-        self._url_master = url_master
         self.multivariant = multivariant if multivariant and multivariant.is_master else None
         self.name = name
         self.force_restart = force_restart
@@ -678,13 +683,8 @@ class HLSStream(HTTPStream):
 
         return json
 
-    @property
-    def url_master(self):
-        """Deprecated"""
-        return self.multivariant.uri if self.multivariant and self.multivariant.uri else self._url_master
-
     def to_manifest_url(self):
-        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else self.url_master
+        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else None
 
         if url is None:
             return super().to_manifest_url()
