@@ -7,8 +7,9 @@ try:
     stdout: BinaryIO = sys.stdout.buffer
 except AttributeError:  # pragma: no cover
     from atexit import register as _atexit_register
+    from pathlib import Path
 
-    stdout = open(devnull, "wb")
+    stdout = Path(devnull).open("wb")
     _atexit_register(stdout.close)
     del _atexit_register
 
