@@ -1,8 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Awaitable, Callable
 from contextlib import nullcontext
-from typing import TYPE_CHECKING, cast
+from typing import TYPE_CHECKING, TypeAlias, cast
 from unittest.mock import ANY, AsyncMock, Mock, call
 
 import pytest
@@ -10,24 +9,24 @@ import trio
 from trio.testing import wait_all_tasks_blocked
 
 from streamlink.compat import ExceptionGroup
-from streamlink.session import Streamlink
 from streamlink.webbrowser.cdp.client import CDPClient, CDPClientSession, RequestPausedHandler
 from streamlink.webbrowser.cdp.connection import CDPConnection, CDPSession
 from streamlink.webbrowser.cdp.devtools.fetch import RequestPaused
 from streamlink.webbrowser.cdp.devtools.target import SessionID, TargetID
 from streamlink.webbrowser.cdp.exceptions import CDPError
-from tests.webbrowser.cdp import FakeWebsocketConnection
 
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
+    from collections.abc import Awaitable, Callable
 
+    from streamlink.session import Streamlink
+    from tests.webbrowser.cdp import FakeWebsocketConnection
 
-TAsyncHandler: TypeAlias = "AsyncMock | Callable[[CDPClientSession, RequestPaused], Awaitable]"
+    TAsyncHandler: TypeAlias = AsyncMock | Callable[[CDPClientSession, RequestPaused], Awaitable]
 
 
 def async_handler(*args, **kwargs):
-    return cast(TAsyncHandler, AsyncMock(*args, **kwargs))
+    return cast("TAsyncHandler", AsyncMock(*args, **kwargs))
 
 
 @pytest.fixture()
